@@ -14,11 +14,28 @@ def set_date_index(df, col='Date'):
     return df
 
 
-def df_transform(prices, options=None, financials=None, trades=None, secondary_prices=None):
+def df_prediction(
+    prices, 
+    options=None, 
+    financials=None, 
+    trades=None, 
+    secondary_prices=None, 
+    sample_predictions=None):
+
     pass
 
 
-def get_data(folder='train_files', root_path=None, supp_files='supplemental_files'):
+def get_data(
+    folder='train_files', 
+    root_path=None, 
+    supp_files='supplemental_files', 
+    prices=None,
+    options=None,
+    financials=None,
+    trades=None,
+    secondary_prices=None,
+    sample_predictions=None
+    ):
     """
     HOW TO HANDLE PREPROCESSING TEXT FOR 
     PREDICTION PIPELINE????
@@ -37,8 +54,16 @@ def get_data(folder='train_files', root_path=None, supp_files='supplemental_file
 
     if root_path is None:
         root_path = f'c:/Users/{computer_name1}/Documents/TokyoData'
-    train_df = pd.read_csv(f'{root_path}/{folder}/stock_prices.csv')
-    tran_df_supplement = pd.read_csv(f'{root_path}/{supp_files}/stock_prices.csv') # New code
+    
+    if prices is not None:
+        train_df = prices
+    else:
+        train_df = pd.read_csv(f'{root_path}/{folder}/stock_prices.csv')
+    
+    if secondary_prices:
+        train_df_supplement = secondary_prices
+    else:
+        train_df_supplement = pd.read_csv(f'{root_path}/{supp_files}/stock_prices.csv') # New code
 
 
     stock_list = pd.read_csv(f'{root_path}/stock_list.csv').drop('Close', axis=1)
@@ -124,6 +149,10 @@ def dataloader_by_stock(
     xtrain, ytrain = preprocess(df_train, 'Target', 1, continous_cols=continous_cols)
     xval, yval = preprocess(df_val, 'Target', 1, continous_cols=continous_cols)
 
+    """
+    TODO:
+    If only one value in test dataset reshape data in transformer!
+    """
     if transform is not None:
         scaler = transform()
         xtrain = scaler.fit_transform(xtrain)
@@ -165,6 +194,8 @@ def dataloader_test_by_stock(
     print('continuos shape:', cont.shape, '', 'categorical shape:', cat.shape)
     xtest, idx = preprocess(cont, target_col, 1, continous_cols=continous_cols, return_idx=return_idx)
 
+    if len(xtest) == 1:
+        xtest = xtest.reshape(1, -1)
     if transformer is not None:
         xtest = transformer.transform(xtest)
     else:
